@@ -1,9 +1,17 @@
+# Copyright edalize contributors
+# Licensed under the 2-Clause BSD License, see LICENSE for details.
+# SPDX-License-Identifier: BSD-2-Clause
+
 from importlib import import_module
 from os.path import dirname
 from pkgutil import walk_packages
 
 NON_TOOL_PACKAGES = [
-    'vunit_hooks'
+    'vunit_hooks',
+    'reporting',
+    'ise_reporting',
+    'vivado_reporting',
+    'quartus_reporting',
 ]
 
 def get_edatool(name):
