@@ -1,3 +1,7 @@
+# Copyright edalize contributors
+# Licensed under the 2-Clause BSD License, see LICENSE for details.
+# SPDX-License-Identifier: BSD-2-Clause
+
 import logging
 import os.path
 import platform
@@ -42,9 +46,15 @@ class Vivado(Edatool):
                         {'name' : 'pnr',
                          'type' : 'String',
                          'desc' : 'P&R tool. Allowed values are vivado (default) and none (to just run synthesis)'},
+                        {'name' : 'jobs',
+                         'type' : 'Integer',
+                         'desc' : 'Number of jobs. Useful for parallelizing OOC (Out Of Context) syntheses.'},
                         {'name' : 'jtag_freq',
                         'type' : 'Integer',
                         'desc' : 'The frequency for jtag communication'},
+                        {'name' : 'source_mgmt_mode',
+                        'type' : 'String',
+                        'desc' : 'Source managment mode. Allowed values are None (unmanaged, default), DisplayOnly (automatically update sources) and All (automatically update sources and compile order)'},
                         {'name' : 'hw_target',
                         'type' : 'Description',
                         'desc' : 'Board identifier (e.g. */xilinx_tcf/Digilent/123456789123A'},
@@ -100,7 +110,6 @@ class Vivado(Edatool):
                                             'output_format' : 'edif',
                                             'yosys_synth_options' : yosys_synth_options,
                                             'yosys_as_subtool' : True,
-                                            'script_name'   : 'yosys.tcl',
                                             }
                                     }
                     }
@@ -142,11 +151,23 @@ class Vivado(Edatool):
                                  self.name+'.tcl',
                                  template_vars)
 
+            jobs = self.tool_options.get('jobs', None)
+
+            run_template_vars = {
+                'jobs' : ' -jobs ' + str(jobs) if jobs is not None else ''
+            }
+
             self.render_template('vivado-run.tcl.j2',
-                                 self.name+"_run.tcl")
+                                 self.name+"_run.tcl",
+                                 run_template_vars)
+
+            synth_template_vars = {
+                'jobs' : ' -jobs ' + str(jobs) if jobs is not None else ''
+            }
 
             self.render_template('vivado-synth.tcl.j2',
-                                 self.name+"_synth.tcl")
+                                 self.name+"_synth.tcl",
+                                 synth_template_vars)
 
         vivado_settings = self.tool_options.get('vivado-settings', None)
         vivado_command = "source {} && vivado".format(vivado_settings) if vivado_settings else "vivado"
