@@ -1,3 +1,7 @@
+# Copyright edalize contributors
+# Licensed under the 2-Clause BSD License, see LICENSE for details.
+# SPDX-License-Identifier: BSD-2-Clause
+
 import logging
 import os.path
 
@@ -26,9 +30,9 @@ class Yosys(Edatool):
                         {'name' : 'makefile_name',
                          'type' : 'String',
                          'desc' : 'Generated makefile name, defaults to $name.mk'},
-                        {'name' : 'script_name',
+                        {'name' : 'yosys_template',
                          'type' : 'String',
-                         'desc' : 'Generated tcl script filename, defaults to $name.mk'},
+                         'desc' : 'TCL template file to use instead of default template'},
                         ],
                     'lists' : [
                         {'name' : 'yosys_synth_options',
@@ -41,6 +45,8 @@ class Yosys(Edatool):
         (src_files, incdirs) = self._get_fileset_files()
         part_of_toolchain = self.tool_options.get('yosys_as_subtool', False)
 
+        yosys_template = self.tool_options.get('yosys_template')
+
         file_table = []
         for f in src_files:
             cmd = ""
@@ -75,7 +81,6 @@ class Yosys(Edatool):
             logger.error("ERROR: arch is not defined.")
 
         makefile_name = self.tool_options.get('makefile_name', self.name + '.mk')
-        script_name = self. tool_options.get('script_name', self.name + '.tcl')
         template_vars = {
                 'verilog_defines'     : "{" + " ".join(verilog_defines) + "}",
                 'verilog_params'      : "\n".join(verilog_params),
@@ -87,14 +92,19 @@ class Yosys(Edatool):
                 'write_command'       : "write_" + output_format,
                 'default_target'      : output_format,
                 'edif_opts'           : '-pvector bra' if arch=='xilinx' else '',
-                'script_name'         : script_name,
+                'yosys_template'      : yosys_template or 'edalize_yosys_template.tcl',
                 'name'                : self.name
         }
 
-        self.render_template('yosys-script-tcl.j2',
-                             script_name,
+        self.render_template('edalize_yosys_procs.tcl.j2',
+                             'edalize_yosys_procs.tcl',
                              template_vars)
 
+        if not yosys_template:
+            self.render_template('yosys-script-tcl.j2',
+                                 'edalize_yosys_template.tcl',
+                                 template_vars)
+
         makefile_name = self.name + '.mk' if part_of_toolchain else 'Makefile'
         self.render_template('yosys-makefile.j2',
                              makefile_name,
